==> HostCMS.Free_6.7.tar.gz: modules/tag/i18n/ru.php <==
<?php
/**
 * Tags.
 *
 * @package HostCMS
 * @subpackage Tag
 * @version 6.x
 * @author Hostmake LLC
 * @copyright © 2005-2017 ООО "Хостмэйк" (Hostmake LLC), http://www.hostcms.ru
 */
return array(
	'model_name' => 'Метки',
	'menu' => 'Метки (теги)',
	'main_form_caption_h1' => 'Метки (теги)',
	'title' => 'Метки (теги)',
	'main_menu' => 'Метка',
	'menu_add' => 'Добавить',
	'markDeleted_success' => 'Метка успешно удалена!',
	'form_edit_add_title_add' => 'Добавление метки',
	'form_edit_add_title_edit' => 'Редактирование метки',
	'id' => 'Идентификатор',
	'name' => '<acronym title="Название метки">Название метки</acronym>',
	'add_tag_name' => '<acronym title="Название метки. Вы можете задать несколько меток. Каждую метку (тег) необходимо добавлять с новой строки">Название метки или меток</acronym>',
	'show_invalid_characters_path' => 'Указаны недопустимые символы (разрешенный диапазон символов а-я, А-Я, a-z, A-Z, 0-9, символ "_", "-" и ".")',
	'description' => '<acronym title="Описание метки">Описание метки</acronym>',
	'form_add_tag_or_tags_description' => '<acronym title="Описание метки или меток">Описание метки или меток</acronym>',
	'error_join_some_tags' => 'Не все теги удалось объединить из-за ошибки прав доступа. Теги %s невозможно объединить под текущим пользователем.',
	'edit_success' => 'Метка успешно отредактирована!',
	'path' => '<acronym title="Название метки в URL, например Disky communication">Название метки в URL</acronym>',
	'move_tags_groups_title' => 'Перенос меток и групп меток',
	'move_tags_groups_id' => "<acronym title=\"Группа, в которую будут перенесены метки и группы\">Родительская группа</acronym>",
	'move_tags_groups_form_button_name' => 'Перенести',
	'move_success' => 'Метки перенесены.',
	'merge_success' => 'Метки объединены.',
	'delete_success' => 'Элемент удален!',
	'undelete_success' => 'Элемент восстановлен!',
	'seo_title' => "<acronym title=\"Значение мета-тега title для тега\">Заголовок (title)</acronym>",
	'seo_description' => "<acronym title=\"Значение мета-тега description для тега\">Описание (description)</acronym>",
	'seo_keywords' => "<acronym title=\"Значение мета-тега keywords для тега\">Ключевые слова (keywords)</acronym>",
);

==> HostCMS.Free_7.0.tar.gz: modules/tag/i18n/ru.php <==
<?php

return array(
	'model_name' => 'Метки',
	'menu' => 'Метки',
	'main_form_caption_h1' => 'Метки',
	'title' => 'Метки',
	'main_menu' => 'Метка',
	'menu_add' => 'Добавить',
	'markDeleted_success' => 'Метка успешно удалена!',
	'form_edit_add_title_add' => 'Добавление метки',
	'form_edit_add_title_edit' => 'Редактирование метки "%s"',
	'id' => 'Идентификатор',
	'name' => 'Название метки',
	'add_tag_name' => '<acronym title="Название метки. Вы можете задать несколько меток. Каждую метку (тег) необходимо добавлять с новой строки">Название метки или меток</acronym>',
	'show_invalid_characters_path' => 'Указаны недопустимые символы (разрешенный диапазон символов а-я, А-Я, a-z, A-Z, 0-9, символ "_", "-" и ".")',
	'description' => 'Описание метки',
	'form_add_tag_or_tags_description' => 'Описание метки или меток',
	'error_join_some_tags' => 'Не все теги удалось объединить из-за ошибки прав доступа. Теги %s невозможно объединить под текущим пользователем.',
	'edit_success' => 'Метка успешно отредактирована!',
	'path' => '<acronym title="Название метки в URL, например Disky communication">Название метки в URL</acronym>',
	'move_tags_groups_title' => 'Перенос меток и групп меток',
	'move_tags_groups_id' => "<acronym title=\"Группа, в которую будут перенесены метки и группы\">Родительская группа</acronym>",
	'move_tags_groups_form_button_name' => 'Перенести',
	'move_success' => 'Метки перенесены.',
	'merge_success' => 'Метки объединены.',
	'delete_success' => 'Элемент удален!',
	'undelete_success' => 'Элемент восстановлен!',
	'seo_title' => "Заголовок (title)",
	'seo_description' => "Описание (description)",
	'seo_keywords' => "Ключевые слова (keywords)",
	'h1' => "Заголовок H1",
);
